package com.example.wc24h;

import android.app.Dialog;
import android.content.Context;
import android.content.SharedPreferences;
import android.view.View;
import android.widget.Button;
import android.widget.RadioButton;

import java.io.File;
import java.sql.Date;
import java.text.DateFormat;

class LoadDialog extends Dialog
{
    private MainActivity        mContext        = null;
    private static final int    profileCount    = 4;
    private RadioButton[]       profileButtons  = new RadioButton[profileCount];
    private int                 selectedProfile = 0;

    LoadDialog(MainActivity a)
    {
        super(a, R.style.dialog_custom_style);

        mContext = a;
        setContentView(R.layout.load_dialog);

        SharedPreferences prefs = mContext.getSharedPreferences("com.example.wc24h", Context.MODE_PRIVATE);
        selectedProfile = prefs.getInt("com.example.wc24h.selected_profile", 0);

        profileButtons[0] = (RadioButton)findViewById(R.id.radioButton1);
        profileButtons[1] = (RadioButton)findViewById(R.id.radioButton2);
        profileButtons[2] = (RadioButton)findViewById(R.id.radioButton3);
        profileButtons[3] = (RadioButton)findViewById(R.id.radioButton4);

        ProfileSelected profileSelected = new ProfileSelected();
        File dir = MainActivity.getSettingsDirFile(mContext);
        DateFormat df = DateFormat.getDateInstance(DateFormat.SHORT);
        for (int i = 0; i < profileButtons.length; i++) {
            profileButtons[i].setOnClickListener(profileSelected);
            File f = new File(dir, MainActivity.getProfileFileName(i));
            String descr = "";
            if (f.exists()) {
                Date d = new Date(f.lastModified());
                descr = df.format(d) + " ";
                WC24hSettings tmp = new WC24hSettings();
                tmp.loadData(dir, MainActivity.getProfileFileName(i));
                descr += tmp.description;
            }
            profileButtons[i].setText((i + 1) + ": " + descr);
        }

        Button cancel = (Button)findViewById(R.id.cancel_button);
        cancel.setOnClickListener(new View.OnClickListener()
        {
            @Override
            public void onClick(View view)
            {
                LoadDialog.this.dismiss();
            }
        });
        Button load = (Button)findViewById(R.id.load_button);
        load.setOnClickListener(new View.OnClickListener()
        {
            @Override
            public void onClick(View view)
            {
                SharedPreferences prefs = mContext.getSharedPreferences("com.example.wc24h", Context.MODE_PRIVATE);
                prefs.edit().putInt("com.example.wc24h.selected_profile", selectedProfile).apply();
                mContext.profileChanged(false);
                LoadDialog.this.dismiss();
            }
        });
        selectProfile(selectedProfile);
    }

    private void selectProfile(int idx)
    {
        for (int i = 0; i < profileButtons.length; i++)
        {
            profileButtons[i].setChecked(i == idx);
        }
    }

    @Override
    protected void onStart()
    {
        super.onStart();
    }

    @Override
    protected void onStop()
    {
        super.onStop();
    }

    private class ProfileSelected implements View.OnClickListener
    {

        @Override
        public void onClick(View view)
        {
            for (int i = 0; i < profileButtons.length; i++)
            {
                if (view == profileButtons[i])
                {
                    profileButtons[i].setChecked(true);
                    selectedProfile = i;
                    selectProfile(i);
                }
                else
                {
                    profileButtons[i].setChecked(false);
                }
            }
        }
    }
}